<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de">
<context>
    <name>QObject</name>
    <message>
        <location filename="../qsynthSetup.cpp" line="37"/>
        <source>(default)</source>
        <translation>(voreingestellt)</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="170"/>
        <source>Usage: %1 [options] [soundfonts] [midifiles]</source>
        <translation>Benutzung: %1 [Optionen] [Soundfonts] [MIDI-Dateien]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="173"/>
        <source>Options</source>
        <translation>Optionen</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="175"/>
        <source>Don&apos;t create a midi driver to read MIDI input events [default = yes]</source>
        <translation>Keinen MIDI-Treiber erzeugen, um eingehende MIDI-Ereignisse zu lesen [Voreinstellung = yes]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="177"/>
        <source>The name of the midi driver to use [oss,alsa,alsa_seq,...]</source>
        <translation>Name des zu benutzenden MIDI-Treibers [oss, alsa, alsa_seq,...]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="179"/>
        <source>The number of midi channels [default = 16]</source>
        <translation>Anzahl der MIDI-Kanäle [Voreinstellung = 16]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="181"/>
        <source>The audio driver [alsa,jack,oss,dsound,...]</source>
        <translation>Der Audiotreiber [alsa, jack, oss, dsound,...]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="183"/>
        <source>Attempt to connect the jack outputs to the physical ports</source>
        <translation>Versuch, die JACK-Ausgänge mit den physikalischen Anschlüssen zu verbinden</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="185"/>
        <source>The number of stereo audio channels [default = 1]</source>
        <translation>Anzahl der Stereo-Audiokanäle [Voreinstellung = 1]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="187"/>
        <source>The number of audio groups [default = 1]</source>
        <translation>Anzahl der Audiogruppen [Voreinstellung = 1]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="189"/>
        <source>Size of each audio buffer</source>
        <translation>Größe eines Audiopuffers</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="191"/>
        <source>Number of audio buffers</source>
        <translation>Anzahl der Audiopuffer</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="193"/>
        <source>Set the sample rate</source>
        <translation>Abtastrate festlegen</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="195"/>
        <source>Turn the reverb on or off [1|0|yes|no|on|off, default = on]</source>
        <translation>Hall ein- oder ausschalten [[1|0|yes|no|on|off, Voreinstellung = on]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="197"/>
        <source>Turn the chorus on or off [1|0|yes|no|on|off, default = on]</source>
        <translation>Chor ein- oder ausschalten [[1|0|yes|no|on|off, Voreinstellung = on]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="199"/>
        <source>Set the master gain [0 &lt; gain &lt; 10, default = 0.2]</source>
        <translation>Ausgangsverstärkung festlegen [0 &lt; gain &lt; 10, Voreinstellung = 0.2]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="201"/>
        <source>Define a setting name=value</source>
        <translation>Einstellung definieren Name=Wert</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="203"/>
        <source>Create and start server [default = no]</source>
        <translation>Server erzeugen und Starten [Voreinstellung = nein]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="205"/>
        <source>Don&apos;t read commands from the shell [ignored]</source>
        <translation>Lese keine Kommandos von der Shell [ignoriert]</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="207"/>
        <source>Dump midi router events</source>
        <translation>Ereignisse des MIDI-Routers ausgeben</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="209"/>
        <source>Print out verbose messages about midi events</source>
        <translation>Zeige ausführliche Meldungen für MIDI-Ereignisse an</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="211"/>
        <source>Show help about command line options</source>
        <translation>Zeige Hilfe zu Kommandozeilenargumenten an</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="213"/>
        <source>Show version information</source>
        <translation>Zeige Versionsinformation an</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="245"/>
        <source>Option -m requires an argument (midi-driver).</source>
        <translation>Option -m benötigt ein Argument (midi-driver).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="254"/>
        <source>Option -K requires an argument (midi-channels).</source>
        <translation>Option -K benötigt ein Argument (midi-channels).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="263"/>
        <source>Option -a requires an argument (audio-driver).</source>
        <translation>Option -a benötigt ein Argument (audio-driver).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="275"/>
        <source>Option -L requires an argument (audio-channels).</source>
        <translation>Option -L benötigt ein Argument (audio-channels).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="284"/>
        <source>Option -G requires an argument (audio-groups).</source>
        <translation>Option -G benötigt ein Argument (audio-groups).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="293"/>
        <source>Option -z requires an argument (audio-bufsize).</source>
        <translation>Option -z benötigt ein Argument (audio-bufsize).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="302"/>
        <source>Option -c requires an argument (audio-bufcount).</source>
        <translation>Option -c benötigt ein Argument (audio-bufcount).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="311"/>
        <source>Option -r requires an argument (sample-rate).</source>
        <translation>Option -R benötigt ein Argument (sample-rate).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="338"/>
        <source>Option -g requires an argument (gain).</source>
        <translation>Option -g benötigt ein Argument (gain).</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="347"/>
        <source>Option -o requires an argument.</source>
        <translation>Option -o benötigt ein Argument.</translation>
    </message>
    <message>
        <location filename="../qsynthOptions.cpp" line="391"/>
        <source>Unknown option &apos;%1&apos;.</source>
        <translation>Unbekannte Option: &apos;%1&apos;.</translation>
    </message>
</context>
<context>
    <name>qsynthAboutForm</name>
    <message>
        <location filename="../qsynthAboutForm.ui" line="33"/>
        <source>About Qsynth</source>
        <translation>Über Qsynth</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.ui" line="61"/>
        <source>&amp;Close</source>
        <translation>&amp;Schließen</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.ui" line="71"/>
        <source>About Qt</source>
        <translation>Über Qt</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="63"/>
        <source>Version</source>
        <translation>Version</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="44"/>
        <source>Debugging option enabled.</source>
        <translation>Debugging-Option aktiviert.</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="47"/>
        <source>System tray disabled.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="50"/>
        <source>Server option disabled.</source>
        <translation>Server-Option deaktiviert.</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="53"/>
        <source>System reset option disabled.</source>
        <translation>System-Zurücksetzen deaktiviert.</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="56"/>
        <source>Bank offset option disabled.</source>
        <translation>Bank-Position-Option deaktiviert.</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="72"/>
        <source>Using: FluidSynth %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="76"/>
        <source>Website</source>
        <translation>Webseite</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="81"/>
        <source>This program is free software; you can redistribute it and/or modify it</source>
        <translation>Dieses Programm ist freie Software; Sie können es gemäß der</translation>
    </message>
    <message>
        <location filename="../qsynthAboutForm.cpp" line="82"/>
        <source>under the terms of the GNU General Public License version 2 or later.</source>
        <translation>GNU General Public License weiterverteilen und/oder modifizieren.</translation>
    </message>
</context>
<context>
    <name>qsynthChannelsForm</name>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="36"/>
        <source>Qsynth: Channels</source>
        <translation>Qsynth: Kanäle</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="56"/>
        <source>Preset &amp;Name:</source>
        <translation>&amp;Benennung:</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="77"/>
        <source>Settings preset name</source>
        <translation>Benennung der Einstellung</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="84"/>
        <source>(default)</source>
        <translation>(voreingestellt)</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="92"/>
        <source>Save settings as current preset name</source>
        <translation>Einstellungen mit aktueller Benennung speichern</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="95"/>
        <source>&amp;Save</source>
        <translation>&amp;Speichern</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="108"/>
        <source>Delete current settings preset</source>
        <translation>Aktuelle Einstellung löschen</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="111"/>
        <source>&amp;Delete</source>
        <translation>&amp;Löschen</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="143"/>
        <source>Channels view</source>
        <translation>Kanalübersicht</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="168"/>
        <source>In</source>
        <translation>Ein</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="173"/>
        <source>Chan</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="178"/>
        <source>Bank</source>
        <translation>Bank</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="183"/>
        <source>Prog</source>
        <translation>Prog</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="188"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="193"/>
        <source>SFID</source>
        <translation>SFID</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.ui" line="198"/>
        <source>Soundfont</source>
        <translation>Soundfont</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.cpp" line="172"/>
        <source>Channels</source>
        <translation>Kanäle</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.cpp" line="333"/>
        <source>Edit</source>
        <translation>Bearbeiten</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.cpp" line="338"/>
        <source>Unset</source>
        <translation>Aufheben</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.cpp" line="342"/>
        <source>Refresh</source>
        <translation>Erneuern</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.cpp" line="470"/>
        <source>Warning</source>
        <translation>Warnung</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.cpp" line="471"/>
        <source>Delete preset:</source>
        <translation>Einstellung löschen:</translation>
    </message>
    <message>
        <location filename="../qsynthChannelsForm.cpp" line="473"/>
        <source>Are you sure?</source>
        <translation>Sind Sie sicher?</translation>
    </message>
</context>
<context>
    <name>qsynthMainForm</name>
    <message>
        <location filename="../qsynthMainForm.ui" line="34"/>
        <source>Qsynth - A fluidsynth Qt GUI Interface</source>
        <translation>Qsynth - Eine Qt basierte grafische Benutzeroberfläche für fluidsynth</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="1019"/>
        <source>Add a new engine</source>
        <translation>Neues Klangmodul hinzufügen</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="1032"/>
        <source>Engine selector (right-click for menu)</source>
        <translation>Klangmodul auswählen (Rechtsklick für Menü)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="1070"/>
        <source>Delete current engine</source>
        <translation>Aktuelles Klangmodul löschen</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="977"/>
        <source>Show/hide the channels view window</source>
        <translation>Zeige/verberge Fenster mit Kanalübersicht</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="980"/>
        <location filename="../qsynthMainForm.cpp" line="1124"/>
        <source>&amp;Channels</source>
        <translation>&amp;Kanäle...</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="130"/>
        <source>Complete engine restart</source>
        <translation>Klangmodul vollständig neu starten</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="133"/>
        <location filename="../qsynthMainForm.cpp" line="1115"/>
        <location filename="../qsynthMainForm.cpp" line="1212"/>
        <source>Re&amp;start</source>
        <translation>&amp;Neu starten</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="948"/>
        <source>Program reset (all channels)</source>
        <translation>Programm zurücksetzen (alle Kanäle)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="951"/>
        <location filename="../qsynthMainForm.cpp" line="1117"/>
        <source>&amp;Reset</source>
        <translation>&amp;Zurücksetzen</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="961"/>
        <source>Show instance settings and configuration dialog</source>
        <translation>Konfigurationsdialog mit den aktuellen Einstellungen anzeigen</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="964"/>
        <location filename="../qsynthMainForm.cpp" line="1129"/>
        <location filename="../qsynthMainForm.cpp" line="1611"/>
        <source>Set&amp;up...</source>
        <translation>Konfi&amp;guration...</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="49"/>
        <source>Master</source>
        <translation>Ausgang</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="67"/>
        <source>&amp;Gain</source>
        <translation>&amp;Verstärkung</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="89"/>
        <location filename="../qsynthMainForm.ui" line="114"/>
        <source>Master Gain</source>
        <translation>Verstärkereinstellung für Ausgangsignal</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="935"/>
        <source>System reset</source>
        <translation>System zurücksetzen</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="938"/>
        <location filename="../qsynthMainForm.cpp" line="1120"/>
        <source>&amp;Panic</source>
        <translation>&amp;Panik</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="149"/>
        <source>Reverb</source>
        <translation>Hall</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="173"/>
        <source>Reverb effect activation</source>
        <translation>Halleffekt aktivieren</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="176"/>
        <source>Ac&amp;tive</source>
        <translation>Ak&amp;tiv</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="189"/>
        <location filename="../qsynthMainForm.ui" line="208"/>
        <source>Reverb Level</source>
        <translation>Hallintensität</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="233"/>
        <source>&amp;Level</source>
        <translation>I&amp;ntensität</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="255"/>
        <location filename="../qsynthMainForm.ui" line="296"/>
        <source>Reverb Width</source>
        <translation>Entfernung zur Schallquelle (Hallradius)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="274"/>
        <source>&amp;Width</source>
        <translation>&amp;Entf.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="321"/>
        <location filename="../qsynthMainForm.ui" line="362"/>
        <source>Reverb Damp Factor</source>
        <translation>Halldämpfung</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="340"/>
        <source>D&amp;amp</source>
        <translation>D&amp;ämpfung</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="387"/>
        <location filename="../qsynthMainForm.ui" line="428"/>
        <source>Reverb Room Size</source>
        <translation>Hallraumgröße</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="406"/>
        <source>R&amp;oom</source>
        <translation>Ra&amp;um</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="456"/>
        <source>Chorus</source>
        <translation>Chor</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="480"/>
        <source>Chorus Modulation Type</source>
        <translation>Typ für Chor-Modulation</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="484"/>
        <source>Sine</source>
        <translation>Sinus</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="489"/>
        <source>Triangle</source>
        <translation>Dreieck</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="509"/>
        <source>T&amp;ype:</source>
        <translation>T&amp;yp:</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="537"/>
        <source>Chorus effect activation</source>
        <translation>Choreffekt aktivieren</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="540"/>
        <source>Act&amp;ive</source>
        <translation>&amp;Aktiv</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="553"/>
        <location filename="../qsynthMainForm.ui" line="600"/>
        <source>Number of Chorus Stages</source>
        <translation>Anzahl der Chorstimmen</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="578"/>
        <source>&amp;N</source>
        <translation>&amp;Stimmen</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="619"/>
        <location filename="../qsynthMainForm.ui" line="666"/>
        <source>Chorus Level</source>
        <translation>Chorintensität</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="644"/>
        <source>Le&amp;vel</source>
        <translation>&amp;Intensität</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="685"/>
        <location filename="../qsynthMainForm.ui" line="738"/>
        <source>Chorus Speed (Hz)</source>
        <translation>Modulationsrate (Hz)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="713"/>
        <source>Chorus Speed Hz</source>
        <translation>Modulationsrate Hz</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="716"/>
        <source>Spee&amp;d</source>
        <translation>Ra&amp;te</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="760"/>
        <location filename="../qsynthMainForm.ui" line="807"/>
        <source>Chorus Depth (ms)</source>
        <translation>Stimmtrennzeit (ms)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="785"/>
        <source>Dept&amp;h</source>
        <translation>Trenn&amp;zeit</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="832"/>
        <source>Output peak level</source>
        <translation>Ausgangspegelanzeige</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="850"/>
        <source>Quit this application</source>
        <translation>Diese Anwendung beenden</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="853"/>
        <location filename="../qsynthMainForm.cpp" line="1162"/>
        <source>&amp;Quit</source>
        <translation>&amp;Beenden</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="866"/>
        <source>Show general options dialog</source>
        <translation>Dialog für die allgemeinen Optionen anzeigen</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="869"/>
        <location filename="../qsynthMainForm.cpp" line="1156"/>
        <source>&amp;Options...</source>
        <translation>&amp;Optionen...</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="882"/>
        <source>Show/hide the messages log window</source>
        <translation>Meldungsfenster anzeigen/verbergen</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="885"/>
        <location filename="../qsynthMainForm.cpp" line="1152"/>
        <source>&amp;Messages</source>
        <translation>&amp;Meldungen...</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="901"/>
        <source>Show information about this application</source>
        <translation>Informationen über diese Anwendung anzeigen</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.ui" line="904"/>
        <source>A&amp;bout...</source>
        <translation>&amp;Über...</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="671"/>
        <location filename="../qsynthMainForm.cpp" line="1502"/>
        <source>Information</source>
        <translation>Information</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="673"/>
        <source>The program will keep running in the system tray.

To terminate the program, please choose &quot;Quit&quot;
in the context menu of the system tray icon.</source>
        <translation>Programm läuft weiter sichtbar als Symbol im Benachrichtigungsfeld.

Zum Beenden des Programms, wählen Sie bitte &quot;Beenden&quot; im
Kontextmenü des Symbols im Benachrichtigungsfeld.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="689"/>
        <source>Don&apos;t show this message again</source>
        <translation>Diese Meldung nicht mehr anzeigen</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="712"/>
        <location filename="../qsynthMainForm.cpp" line="1326"/>
        <location filename="../qsynthMainForm.cpp" line="2084"/>
        <location filename="../qsynthMainForm.cpp" line="2114"/>
        <source>Warning</source>
        <translation>Warnung</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="714"/>
        <source>is about to terminate.</source>
        <translation>soll beendet werden.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="715"/>
        <location filename="../qsynthMainForm.cpp" line="1329"/>
        <source>Are you sure?</source>
        <translation>Sind Sie sicher?</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="725"/>
        <source>Don&apos;t ask this again</source>
        <translation>Nicht nochmal nachfragen</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="805"/>
        <source>Loading soundfont: &quot;%1&quot;</source>
        <translation>Lade Soundfont: &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="816"/>
        <location filename="../qsynthMainForm.cpp" line="1787"/>
        <source>Failed to load the soundfont: &quot;%1&quot;.</source>
        <translation>Fehler beim Laden von Soundfont: &quot;%1&quot;.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="824"/>
        <source>Playing MIDI file: &quot;%1&quot;</source>
        <translation>Spiele MIDI-Datei ab: &quot;%1&quot;</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="831"/>
        <source>Failed to play MIDI file: &quot;%1&quot;.</source>
        <translation>Fehler beim Abspielen der MIDI-Datei: &quot;%1&quot;.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="994"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1097"/>
        <source>&amp;Hide</source>
        <translation>&amp;Verbergen</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1093"/>
        <source>Mi&amp;nimize</source>
        <translation>&amp;Minimieren</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1098"/>
        <source>S&amp;how</source>
        <translation>&amp;Anzeigen</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1094"/>
        <source>Rest&amp;ore</source>
        <translation>Wieder&amp;herstellen</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1107"/>
        <location filename="../qsynthMainForm.cpp" line="1605"/>
        <source>&amp;New engine...</source>
        <translation>&amp;Neues Klangmodul...</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1109"/>
        <location filename="../qsynthMainForm.cpp" line="1607"/>
        <source>&amp;Delete</source>
        <translation>&amp;Löschen</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1115"/>
        <location filename="../qsynthMainForm.cpp" line="1214"/>
        <source>&amp;Start</source>
        <translation>&amp;Starten</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1135"/>
        <source>Engines</source>
        <translation>Klangmodule</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1327"/>
        <source>Delete fluidsynth engine:</source>
        <translation>Lösche fluidsynth Klangmodul:</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1504"/>
        <source>Some settings will be only effective
next time you start this program.</source>
        <translation>Einige Einstellungen werden erst nach
einem Neustart des Programms wirksam.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1746"/>
        <source>Creating synthesizer engine</source>
        <translation>Erzeuge Synthesizer-Klangmodul</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1750"/>
        <source>Failed to create the synthesizer.

Cannot continue without it.</source>
        <translation>Fehler beim Erzeugen des Synthesizers.

Kann ohne ihn nicht weitermachen.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1781"/>
        <source>Loading soundfont: &quot;%1&quot; (bank offset %2)</source>
        <translation>Lade Soundfont: &quot;%1&quot; (Bankposition %2)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1794"/>
        <source>Failed to set bank offset (%1) for soundfont: &quot;%2&quot;.</source>
        <translation>Fehler beim Setzen des Bankpositionswertes (%1) für Soundfont: &quot;%2&quot;.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1804"/>
        <source>Creating audio driver (%1)</source>
        <translation>Erzeuge Audiotreiber (%1)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1818"/>
        <source>Failed to create the audio driver (%1).

Cannot continue without it.</source>
        <translation>Fehler beim Erzeugen des Audiotreibers (%1).

Kann nicht ohne ihn fortfahren.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1831"/>
        <source>Creating MIDI router (%1)</source>
        <translation>Erzeuge MIDI-Router (%1)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1840"/>
        <source>Failed to create the MIDI input router (%1).

No MIDI input will be available.</source>
        <translation>Fehler beim Erzeugen des Routers für den MIDI-Eingang (%1).

Es wird kein MIDI-Eingang verfügbar sein.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1846"/>
        <source>Creating MIDI driver (%1)</source>
        <translation>Erzeuge MIDI-Treiber (%1)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1855"/>
        <source>Failed to create the MIDI driver (%1).

No MIDI input will be available.</source>
        <translation>Fehler beim Erzeugen des MIDI-Treibers (%1).

MIDI-Eingang wird nicht zur Verfügung stehen.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1862"/>
        <source>Creating MIDI player</source>
        <translation>Erzeuge MIDI-Spieler</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1866"/>
        <source>Failed to create the MIDI player.

Continuing without a player.</source>
        <translation>Fehler beim Erzeugen des MIDI-Spielers

MAche ohne Spieler weiter.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1876"/>
        <source>Creating server</source>
        <translation>Erzeuge Server</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1898"/>
        <source>Failed to create the server.

Continuing without it.</source>
        <translation>Fehler beim Erzeugen des Servers.

Mache ohne in weiter.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1902"/>
        <source>Server mode disabled.

Continuing without it.</source>
        <translation>Server-Modus deaktiviert.

Mache ohne ihn weiter.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1936"/>
        <source>Synthesizer engine started.</source>
        <translation>Synthesizer-Klangmodul gestartet.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1976"/>
        <source>Destroying server</source>
        <translation>Fahre Server herunter</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1984"/>
        <source>Stopping MIDI player</source>
        <translation>MIDI-Spieler wird angehalten</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1986"/>
        <source>Waiting for MIDI player to terminate</source>
        <translation>Warte auf Beenden des MIDI-Spielers</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1988"/>
        <source>Destroying MIDI player</source>
        <translation>Beende MIDI-Spieler</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="1996"/>
        <source>Destroying MIDI driver</source>
        <translation>Beende MIDI-Treiber</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2000"/>
        <source>Destroying MIDI router</source>
        <translation>Beende MIDI-Router</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2007"/>
        <source>Destroying audio driver</source>
        <translation>Beende Audiotreiber</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2022"/>
        <source>Unloading soundfont: &quot;%1&quot; (SFID=%2)</source>
        <translation>Entlade Soundfont: &quot;%1&quot; (SFID=%2)</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2026"/>
        <source>Failed to unload the soundfont: &quot;%1&quot;.</source>
        <translation>Fehler beim Entladen von Soundfont: &quot;%1&quot;.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2033"/>
        <source>Destroying synthesizer engine</source>
        <translation>Beende Synthesizer-Klangmodul</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2037"/>
        <source>Synthesizer engine terminated.</source>
        <translation>Synthesizer-Klangmodul beendet.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2085"/>
        <source>New settings will be effective after
restarting all fluidsynth engines.</source>
        <translation>Die neuen Einstellungen werden erst nach einem
Neustart aller fluidsynth-Klangmodule effektiv sein.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2087"/>
        <location filename="../qsynthMainForm.cpp" line="2118"/>
        <source>Please note that this operation may cause
temporary MIDI and Audio disruption.</source>
        <translation>Bitte beachten Sie, dass dieser Neustart temporäre
MIDI- und Audiounterbrechungen verursacht.</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2089"/>
        <source>Do you want to restart all engines now?</source>
        <translation>Möchten Sie nun alle Klangmodule neu starten?</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2115"/>
        <source>New settings will be effective after
restarting the fluidsynth engine:</source>
        <translation>Die neuen Einstellungen werden erst nach einem
Neustart dieses fluidsynth-Klangmoduls effektiv sein:</translation>
    </message>
    <message>
        <location filename="../qsynthMainForm.cpp" line="2120"/>
        <source>Do you want to restart the engine now?</source>
        <translation>Möchten Sie das Klangmodul nun neu starten?</translation>
    </message>
</context>
<context>
    <name>qsynthMessagesForm</name>
    <message>
        <location filename="../qsynthMessagesForm.ui" line="42"/>
        <source>Qsynth: Messages</source>
        <translation>Qsynth: Meldungen</translation>
    </message>
    <message>
        <location filename="../qsynthMessagesForm.ui" line="54"/>
        <source>Messages output log</source>
        <translation>Historie der aufgezeichneten Meldungen</translation>
    </message>
    <message>
        <location filename="../qsynthMessagesForm.cpp" line="136"/>
        <source>Logging stopped --- %1 ---</source>
        <translation>Aufzeichung angehalten --- %1 ---</translation>
    </message>
    <message>
        <location filename="../qsynthMessagesForm.cpp" line="146"/>
        <source>Logging started --- %1 ---</source>
        <translation>Aufzeichnung gestartet --- %1 ---</translation>
    </message>
</context>
<context>
    <name>qsynthOptionsForm</name>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="33"/>
        <source>Qsynth: Options</source>
        <translation>Qsynth: Optionen</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="43"/>
        <source>Display</source>
        <translation>Anzeige</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="55"/>
        <source>Messages</source>
        <translation>Meldungen</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="82"/>
        <source>Sample messages text font display</source>
        <translation>Schriftart für das Meldungsfenster</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="110"/>
        <source>Select font for the messages text display</source>
        <translation>Schriftart für Meldungsfenster auswählen</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="113"/>
        <source>&amp;Font...</source>
        <translation>Schri&amp;ftart...</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="145"/>
        <source>Whether to keep a maximum number of lines in the messages window</source>
        <translation>Maximale Anzahl der angezeigten Meldungen limitieren</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="148"/>
        <source>&amp;Messages limit:</source>
        <translation>&amp;Max. Meldungen:</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="161"/>
        <source>The maximum number of message lines to keep in view</source>
        <translation>Maximale Anzahl angezeigter Zeilen</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="171"/>
        <source>100</source>
        <translation>100</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="176"/>
        <source>250</source>
        <translation>250</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="181"/>
        <source>500</source>
        <translation>500</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="186"/>
        <source>1000</source>
        <translation>1000</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="191"/>
        <source>2500</source>
        <translation>2500</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="196"/>
        <source>5000</source>
        <translation>5000</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="213"/>
        <source>Logging</source>
        <translation>Aufzeichnung</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="236"/>
        <source>Messages log file</source>
        <translation>Protokolldatei</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="267"/>
        <source>Browse for the messages log file location</source>
        <translation>Ablage für Protokolldatei nachschlagen</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="270"/>
        <source>...</source>
        <translation>...</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="283"/>
        <source>Whether to activate a messages logging to file.</source>
        <translation>Meldungen in einer Protokolldatei aufzeichen.</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="440"/>
        <source>Other</source>
        <translation>Weiteres</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="455"/>
        <source>Whether to ask for confirmation on application exit</source>
        <translation>Beim Schließen der Anwendung nachfragen</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="458"/>
        <source>&amp;Confirm application close</source>
        <translation>&amp;Schließen der Anwendung bestätigen</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="471"/>
        <source>Whether to keep all child windows on top of the main window</source>
        <translation>Alle Unterfenster oberhalb des Hauptfensters anordnen</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="474"/>
        <source>&amp;Keep child windows always on top</source>
        <translation>Unterfenster immer &amp;oberhalb anordnen</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="487"/>
        <source>Whether to capture standard output (stdout/stderr) into messages window</source>
        <translation>Standardausgabe (stdout/stderr) in das Meldungsfenster umleiten</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="490"/>
        <source>Capture standard &amp;output</source>
        <translation>Standardausgabe &amp;umleiten</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="503"/>
        <source>Whether to monitor and show engine output peak level meters</source>
        <translation>Ausgangspegelinstrument anzeigen</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="506"/>
        <source>Output &amp;peak level meters</source>
        <translation>Ausgangs&amp;pegelinstrument anzeigen</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="532"/>
        <source>Whether to enable the system tray icon</source>
        <translation>Anwendungssymbol im Benachrichtigungsfeld anzeigen</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="535"/>
        <source>&amp;Enable system tray icon</source>
        <translation>S&amp;ymbol im Benachrichtigungsfeld anzeigen</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="564"/>
        <source>Whether to start minimized to system tray</source>
        <translation>Anwendung minimiert als Symbol im Benachrichtigungsfeld starten</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="567"/>
        <source>Start minimi&amp;zed to system tray</source>
        <translation>Minimiert im &amp;Benachrichtigungsfeld starten</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.cpp" line="246"/>
        <source>Warning</source>
        <translation>Warnung</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.cpp" line="247"/>
        <source>Some options have been changed.</source>
        <translation>Einige Einstellungen wurden verändert.</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.cpp" line="248"/>
        <source>Do you want to apply the changes?</source>
        <translation>Möchten Sie die Änderungen anwenden?</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.cpp" line="307"/>
        <source>Messages Log</source>
        <translation>Meldungsprotokoll</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.cpp" line="309"/>
        <source>Log files</source>
        <translation>Protokolldateien</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="302"/>
        <source>Knobs</source>
        <translation>Drehregler</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="333"/>
        <source>Graphic style for knobs</source>
        <translation>Graphischer Stil der Drehregler</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="337"/>
        <source>Classic</source>
        <translation>Klassisch</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="342"/>
        <source>Vokimon</source>
        <translation>Vokimon</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="347"/>
        <source>Peppino</source>
        <translation>Peppino</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="357"/>
        <location filename="../qsynthOptionsForm.ui" line="413"/>
        <source>Legacy</source>
        <translation>Legacy</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="406"/>
        <source>Mouse motion behavior for knobs</source>
        <translation>Reaktion der Drehregler auf Mausbewegung</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="418"/>
        <source>Radial</source>
        <translation>Radial</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="423"/>
        <source>Linear</source>
        <translation>Linear</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="548"/>
        <source>Whether to show system tray message on main window close</source>
        <translation>Nachrichten des Benachrichtigungsfelds beim Schließen des Hauptfensters anzeigen</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="551"/>
        <source>Sho&amp;w system tray message on close</source>
        <translation>&amp;Nachrichten des Benachrichtigungsfelds beim Beenden anzeigen</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="599"/>
        <source>Defaults</source>
        <translation>Voreinstellungen</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="636"/>
        <source>&amp;Base font size:</source>
        <translation>Schrift&amp;größe:</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="655"/>
        <source>Base application font size (pt.)</source>
        <translation>Standardschriftgröße für die Anwendung</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="662"/>
        <source>(default)</source>
        <translation>(voreingestellt)</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="677"/>
        <source>8</source>
        <translation>8</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="682"/>
        <source>9</source>
        <translation>9</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="687"/>
        <source>10</source>
        <translation>10</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="692"/>
        <source>11</source>
        <translation>11</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="697"/>
        <source>12</source>
        <translation>12</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="286"/>
        <source>Messages &amp;log file:</source>
        <translation>Protokoll&amp;datei:</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="317"/>
        <source>Kno&amp;b graphic style:</source>
        <translation>Dreh&amp;reglerstil:</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="387"/>
        <source>Mouse motion be&amp;havior:</source>
        <translation>Reaktion auf Mausbe&amp;wegung:</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="667"/>
        <source>6</source>
        <translation>6</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="672"/>
        <source>7</source>
        <translation>7</translation>
    </message>
    <message>
        <location filename="../qsynthOptionsForm.ui" line="352"/>
        <source>Skulpture</source>
        <translation>Skulpture</translation>
    </message>
</context>
<context>
    <name>qsynthPresetForm</name>
    <message>
        <location filename="../qsynthPresetForm.ui" line="33"/>
        <source>Qsynth: Channel Preset</source>
        <translation>Qsynth: Kanalvoreinstellung</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="59"/>
        <source>Preset</source>
        <translation>Voreinstellung</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="87"/>
        <source>Bank selector</source>
        <translation>Bank einstellen</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="112"/>
        <source>Bank</source>
        <translation>Bank</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="118"/>
        <source>Program selector</source>
        <translation>Programm einstellen</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="143"/>
        <source>Prog</source>
        <translation>Prog</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="148"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="153"/>
        <source>SFID</source>
        <translation>SFID</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="158"/>
        <source>Soundfont</source>
        <translation>Soundfont</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="167"/>
        <source>Whether to preview the current selection</source>
        <translation>Voransicht für akktuelle Auswahl anzeigen</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.ui" line="170"/>
        <source>Preview</source>
        <translation>Voransicht</translation>
    </message>
    <message>
        <location filename="../qsynthPresetForm.cpp" line="147"/>
        <source>Channel %1</source>
        <translation>Kanal %1</translation>
    </message>
</context>
<context>
    <name>qsynthSetupForm</name>
    <message>
        <location filename="../qsynthSetupForm.ui" line="34"/>
        <source>Qsynth: Setup</source>
        <translation>Qsynth: Konfiguration</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="51"/>
        <source>Engine &amp;Name:</source>
        <translation>Klangmodul&amp;benennung:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="64"/>
        <source>Engine display name</source>
        <translation>Angezeigter Name des Klangmoduls</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="93"/>
        <source>&amp;MIDI</source>
        <translation>&amp;MIDI</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="131"/>
        <location filename="../qsynthSetupForm.ui" line="685"/>
        <source>MIDI device name</source>
        <translation>MIDI-Gerätename</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="161"/>
        <source>MIDI &amp;Device:</source>
        <translation>MIDI-&amp;Gerät:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="99"/>
        <source>&amp;MIDI Driver:</source>
        <translation>MIDI-&amp;Treiber:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="151"/>
        <source>Input MIDI driver</source>
        <translation>Treiber für MIDI-Eingang</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="283"/>
        <source>MIDI Client Name ID (ALSA/CoreMidi):</source>
        <translation>MIDI-Client-Name-ID (ALSA/CoreMidi):</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="296"/>
        <source>ALSA Sequencer client name identification</source>
        <translation>Identifikationsname fürs Anmelden beim ALSA-Sequenzer</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="303"/>
        <source>pid</source>
        <translation>pid</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="308"/>
        <location filename="../qsynthSetupForm.ui" line="781"/>
        <source>qsynth</source>
        <translation>qsynth</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="115"/>
        <source>Whether to show MIDI router events on messages window</source>
        <translation>MIDI-Router-Ereignisse im Meldungsfenster anzeigen </translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="118"/>
        <source>&amp;Dump MIDI router events</source>
        <translation>MIDI-&amp;Router-Ereignisse ausgeben</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="177"/>
        <source>Print out verbose messages about MIDI events</source>
        <translation>Ausführliche Meldungen über MIDI-Ereignisse ausgeben</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="180"/>
        <source>&amp;Verbose MIDI event messages</source>
        <translation>Aus&amp;führliche Meldungen über MIDI-Ereignisse</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="203"/>
        <source>Number of MIDI channels</source>
        <translation>Anzahl der MIDI-Kanäle</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="190"/>
        <source>MIDI &amp;Channels:</source>
        <translation>MIDI-&amp;Kanäle:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="141"/>
        <source>Enable MIDI input</source>
        <translation>MIDI-Eingang aktivieren</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="144"/>
        <source>Enable MIDI &amp;Input</source>
        <translation>MI&amp;DI-Eingang aktivieren</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="236"/>
        <source>gm</source>
        <translation>gm</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="241"/>
        <source>gs</source>
        <translation>gs</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="246"/>
        <source>mma</source>
        <translation>mma</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="251"/>
        <source>xs</source>
        <translation>xs</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="219"/>
        <source>MIDI &amp;Bank Select mode:</source>
        <translation>MIDI-&amp;Bank Einstellmodus:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="229"/>
        <source>MIDI Bank Select mode</source>
        <translation>MIDI-Bank Einstellmodus</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="358"/>
        <source>&amp;Audio</source>
        <translation>&amp;Audio</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="382"/>
        <source>Sample &amp;Format:</source>
        <translation>Au&amp;flösung:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="395"/>
        <source>Output audio driver</source>
        <translation>Audiotreiber für Ausgabe</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="405"/>
        <source>Sample format</source>
        <translation>Numerisches Format des digitalisierten Audiosignals</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="412"/>
        <source>Period size in bytes (audio buffer size)</source>
        <translation>Größe des Audiopuffers in Byte</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="419"/>
        <location filename="../qsynthSetupForm.ui" line="564"/>
        <source>64</source>
        <translation>64</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="424"/>
        <source>128</source>
        <translation>128</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="429"/>
        <source>256</source>
        <translation>256</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="434"/>
        <source>512</source>
        <translation>512</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="439"/>
        <source>1024</source>
        <translation>1024</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="444"/>
        <source>2048</source>
        <translation>2048</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="449"/>
        <source>4096</source>
        <translation>4096</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="454"/>
        <source>8192</source>
        <translation>8129</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="462"/>
        <source>Buffer Cou&amp;nt:</source>
        <translation>Pufferan&amp;zahl:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="475"/>
        <source>Sample rate in samples per second (Hz)</source>
        <translation>Abtastrate in Hz (Samples pro Sekunde)</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="485"/>
        <source>22050</source>
        <translation>22050</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="490"/>
        <source>44100</source>
        <translation>44100</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="495"/>
        <source>48000</source>
        <translation>48000</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="500"/>
        <source>88200</source>
        <translation>88200</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="505"/>
        <source>96000</source>
        <translation>96000</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="519"/>
        <source>Sample &amp;Rate:</source>
        <translation>Abtast&amp;rate:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="532"/>
        <source>Period count (number of audio buffers)</source>
        <translation>Anzahl der Perioden (Anzahl der Audiopuffer)</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="539"/>
        <source>2</source>
        <translation>2</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="544"/>
        <source>4</source>
        <translation>4</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="549"/>
        <source>8</source>
        <translation>8</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="554"/>
        <source>16</source>
        <translation>16</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="559"/>
        <source>32</source>
        <translation>32</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="572"/>
        <source>Buffer &amp;Size:</source>
        <translation>Puffergr&amp;öße:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="585"/>
        <source>&amp;Audio Driver:</source>
        <translation>Audio&amp;treiber:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="605"/>
        <source>Audio &amp;Device:</source>
        <translation>Audio&amp;gerät:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="624"/>
        <source>Audio &amp;Channels:</source>
        <translation>Audio&amp;kanäle:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="637"/>
        <source>Number of audio groups</source>
        <translation>Anzahl der Audiogruppen</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="650"/>
        <source>Number of enabled polyphonic voices</source>
        <translation>Anzahl der aktiven Polyphoniestimmen</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="666"/>
        <source>Number of stereo audio channels</source>
        <translation>Anzahl der Stereo-Audiokanäle</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="698"/>
        <source>&amp;Polyphony:</source>
        <translation>&amp;Polyphonie:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="727"/>
        <source>Audio &amp;Groups:</source>
        <translation>A&amp;udiogruppen:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="753"/>
        <source>JACK Client Name &amp;ID:</source>
        <translation>JACK-Client &amp;Identifikationsname:</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="766"/>
        <source>JACK client name identification</source>
        <translation>Identifikationsname als JACK-Client</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="776"/>
        <source>fluidsynth</source>
        <translation>fluidsynth</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="804"/>
        <source>Attempt to connect the JACK outputs to the physical ports</source>
        <translation>Versuche, die JACK-Ausgänge mit den physikalischen Anschlüssen zuverbinden</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="807"/>
        <source>Auto Connect &amp;JACK Outputs</source>
        <translation>&amp;JACK-Ausgänge automatisch verbinden</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="814"/>
        <source>Create multiple JACK output ports for channels, groups and effects</source>
        <translation>Erzeuge mehrere JACK-Ausgänge für Kanäle, Gruppen und Effekte</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="817"/>
        <source>&amp;Multiple JACK Outputs</source>
        <translation>Me&amp;hrere JACK-Ausgänge</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="841"/>
        <source>&amp;Soundfonts</source>
        <translation>&amp;Soundfonts</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="856"/>
        <source>Soundfont stack</source>
        <translation>Soundfont-Stapel</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="878"/>
        <source>SFID</source>
        <translation>SFID</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="883"/>
        <location filename="../qsynthSetupForm.ui" line="1025"/>
        <source>Name</source>
        <translation>Name</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="888"/>
        <source>Offset</source>
        <translation>Position</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="901"/>
        <source>Open soundfont file for loading</source>
        <translation>Soundfont-Datei zum Laden öffnen</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="904"/>
        <source>&amp;Open...</source>
        <translation>&amp;Öffnen...</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="914"/>
        <source>Edit selected soundfont bank offset</source>
        <translation>Positionswert der gewählten Soundfont-Bank bearbeiten</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="917"/>
        <source>&amp;Edit</source>
        <translation>Bea&amp;rbeiten</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="927"/>
        <source>Remove selected soundfont from stack</source>
        <translation>Gewählten Soundfont aus Stapel entfernen</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="930"/>
        <source>&amp;Remove</source>
        <translation>En&amp;tfernen</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="953"/>
        <source>Move up selected soundfont towards the top of stack</source>
        <translation>Gewählten Soundfont im Stapel nach oben bewegen</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="956"/>
        <source>&amp;Up</source>
        <translation>A&amp;uf</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="966"/>
        <source>Move down selected soundfont towards the bottom of stack</source>
        <translation>Gewählten Soundfont im Stapel nach unten bewegen</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="969"/>
        <source>&amp;Down</source>
        <translation>A&amp;b</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="982"/>
        <source>S&amp;ettings</source>
        <translation>&amp;Einstellungen</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1030"/>
        <source>Type</source>
        <translation>Typ</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1035"/>
        <source>Realtime</source>
        <translation>Realtime</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1040"/>
        <source>Current</source>
        <translation>Aktuell</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1045"/>
        <source>Default</source>
        <translation>Voreinstellung</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1050"/>
        <source>Min</source>
        <translation>Min</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1055"/>
        <source>Max</source>
        <translation>Max</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.ui" line="1060"/>
        <source>Options</source>
        <translation>Optionen</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="362"/>
        <source>Setup</source>
        <translation>Konfigurieren</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="573"/>
        <location filename="../qsynthSetupForm.cpp" line="832"/>
        <source>Warning</source>
        <translation>Warnung</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="574"/>
        <source>Some settings have been changed.</source>
        <translation>Einige Einstellungen wurden geändert.</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="575"/>
        <source>Do you want to apply the changes?</source>
        <translation>Möchten Sie die Änderungen anwenden?</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="770"/>
        <source>Open...</source>
        <translation>Öffnen...</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="775"/>
        <source>Edit</source>
        <translation>Bearbeiten</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="780"/>
        <source>Remove</source>
        <translation>Entfernen</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="785"/>
        <source>Move Up</source>
        <translation>Auf</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="789"/>
        <source>Move Down</source>
        <translation>Ab</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="815"/>
        <location filename="../qsynthSetupForm.cpp" line="817"/>
        <source>Soundfont files</source>
        <translation>Soundfont-Dateien</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="833"/>
        <source>Soundfont file already on list</source>
        <translation>Soundfont-Datei ist bereits Bestandteil der Liste</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="835"/>
        <source>Add anyway?</source>
        <translation>Dennoch hinzufügen?</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="862"/>
        <source>Error</source>
        <translation>Fehler</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="863"/>
        <source>Failed to add soundfont file</source>
        <translation>Fehler beim Hinzufügen der Soundfont-Datei</translation>
    </message>
    <message>
        <location filename="../qsynthSetupForm.cpp" line="865"/>
        <source>Please, check for a valid soundfont file.</source>
        <translation>Bitte wählen Sie eine gültige Soundfont-Datei.</translation>
    </message>
</context>
</TS>
